@@ -2,13 +2,13 @@
 //! to create firmwares for the fabulous [BBC micro:bit](https://microbit.org)
 //! microcontroller board.
 //!
-//! This crate is for the original micro:bit (V1) pictured below on the left. If
+//! This crate is for the new micro:bit (V2) pictured below on the right. If
 //! your micro:bit looks like the one on the right you need the
-//! [microbit-v2](https://crates.io/crates/microbit-v2) crate.
+//! [microbit](https://crates.io/crates/microbit) crate.
 //!
 //! [<img src="https://github.com/microbit-foundation/microbit-svg/raw/master/microbit-drawing-back-1-5.png" width="372px" height="300px">](https://github.com/microbit-foundation/microbit-svg/blob/master/microbit-drawing-back-1-5.png)
 //! [<img src="https://github.com/microbit-foundation/microbit-svg/raw/master/microbit-drawing-back-2.png" width="372px" height="300px">](https://github.com/microbit-foundation/microbit-svg/blob/master/microbit-drawing-back-2.png)
-#![doc(html_root_url = "https://docs.rs/microbit/0.11.0")]
+#![doc(html_root_url = "https://docs.rs/microbit-v2/0.10.0")]
 #![no_std]
 #![deny(missing_docs)]
 #![allow(non_camel_case_types)]
